@@ -15,9 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
- *
- * $Id: audio_directx2_out.c,v 1.9 2006/07/16 16:18:09 dsalt Exp $
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  *
  *
  * xine audio output plugin using DirectX
@@ -957,7 +955,7 @@ static ao_driver_t *open_plugin(audio_driver_class_t *class_gen, const void *dat
 
   lprintf("open plugin called\n");
 
-  this = (dx2_driver_t *)xine_xmalloc(sizeof(dx2_driver_t));
+  this = calloc(1, sizeof(dx2_driver_t));
   if (!this)
     return NULL;
 
@@ -1011,7 +1009,7 @@ static void *init_class(xine_t *xine, void *data) {
 
   lprintf("init class\n");
 
-  this = (dx2_class_t *)xine_xmalloc(sizeof(dx2_class_t));
+  this = calloc(1, sizeof(dx2_class_t));
   if (!this)
     return NULL;
 
