@@ -121,6 +121,10 @@ struct ff_video_decoder_s {
   yuv_planes_t      yuv;
 
   AVPaletteControl  palette_control;
+
+#ifdef LOG
+  enum PixelFormat  debug_fmt;
+#endif
 };
 
 
@@ -152,7 +156,7 @@ static int get_buffer(AVCodecContext *context, AVFrame *av_frame){
   
   avcodec_align_dimensions(context, &width, &height);
 
-  if( this->context->pix_fmt != PIX_FMT_YUV420P ) {
+  if( this->context->pix_fmt != PIX_FMT_YUV420P && this->context->pix_fmt != PIX_FMT_YUVJ420P ) {
     if (!this->is_direct_rendering_disabled) {
       xprintf(this->stream->xine, XINE_VERBOSITY_LOG, 
               _("ffmpeg_video_dec: unsupported frame format, DR1 disabled.\n"));
@@ -377,7 +381,7 @@ static void init_video_codec (ff_video_decoder_t *this, unsigned int codec_type)
 
   /* Some codecs (eg rv10) copy flags in init so it's necessary to set
    * this flag here in case we are going to use direct rendering */
-  if(this->codec->capabilities & CODEC_CAP_DR1) {
+  if(this->codec->capabilities & CODEC_CAP_DR1 && this->codec->id != CODEC_ID_H264) {
     this->context->flags |= CODEC_FLAG_EMU_EDGE;
   }
  
@@ -589,6 +593,11 @@ static void ff_convert_frame(ff_video_decoder_t *this, vo_frame_t *img) {
   int         y;
   uint8_t    *dy, *du, *dv, *sy, *su, *sv;
 
+#ifdef LOG
+  if (this->debug_fmt != this->context->pix_fmt)
+    printf ("frame format == %08x\n", this->debug_fmt = this->context->pix_fmt);
+#endif
+
   dy = img->base[0];
   du = img->base[1];
   dv = img->base[2];
@@ -886,7 +895,7 @@ static void ff_handle_preview_buffer (ff_video_decoder_t *this, buf_element_t *b
   if (codec_type == BUF_VIDEO_MPEG) {
     this->is_mpeg12 = 1;
     if ( this->mpeg_parser == NULL ) {
-      this->mpeg_parser = xine_xmalloc(sizeof(mpeg_parser_t));
+      this->mpeg_parser = calloc(1, sizeof(mpeg_parser_t));
       mpeg_parser_init(this->mpeg_parser);
       this->decoder_init_mode = 0;
     }
@@ -941,7 +950,7 @@ static void ff_handle_header_buffer (ff_video_decoder_t *this, buf_element_t *bu
         
         this->context->sub_id = _X_BE_32(&this->buf[30]);
 
-        this->context->slice_offset = xine_xmalloc(sizeof(int)*SLICE_OFFSET_SIZE);
+        this->context->slice_offset = calloc(SLICE_OFFSET_SIZE, sizeof(int));
         this->slice_offset_size = SLICE_OFFSET_SIZE;
 
         this->context->extradata_size = this->size - 26;
@@ -989,8 +998,8 @@ static void ff_handle_special_buffer (ff_video_decoder_t *this, buf_element_t *b
 
     lprintf("BUF_SPECIAL_STSD_ATOM\n");
     this->context->extradata_size = buf->decoder_info[2];
-    this->context->extradata = xine_xmalloc(buf->decoder_info[2] + 
-                                            FF_INPUT_BUFFER_PADDING_SIZE);
+    this->context->extradata = malloc(buf->decoder_info[2] + 
+				      FF_INPUT_BUFFER_PADDING_SIZE);
     memcpy(this->context->extradata, buf->decoder_info_ptr[2],
       buf->decoder_info[2]);
 
@@ -999,8 +1008,8 @@ static void ff_handle_special_buffer (ff_video_decoder_t *this, buf_element_t *b
     
     lprintf("BUF_SPECIAL_DECODER_CONFIG\n");
     this->context->extradata_size = buf->decoder_info[2];
-    this->context->extradata = xine_xmalloc(buf->decoder_info[2] +
-                                            FF_INPUT_BUFFER_PADDING_SIZE);
+    this->context->extradata = malloc(buf->decoder_info[2] +
+				      FF_INPUT_BUFFER_PADDING_SIZE);
     memcpy(this->context->extradata, buf->decoder_info_ptr[2],
       buf->decoder_info[2]);
       
@@ -1548,7 +1557,7 @@ static video_decoder_t *ff_video_open_plugin (video_decoder_class_t *class_gen,
 
   lprintf ("open_plugin\n");
 
-  this = (ff_video_decoder_t *) xine_xmalloc (sizeof (ff_video_decoder_t));
+  this = calloc(1, sizeof (ff_video_decoder_t));
 
   this->video_decoder.decode_data         = ff_decode_data;
   this->video_decoder.flush               = ff_flush;
@@ -1567,7 +1576,7 @@ static video_decoder_t *ff_video_open_plugin (video_decoder_class_t *class_gen,
   
   this->decoder_ok        = 0;
   this->decoder_init_mode = 1;
-  this->buf               = xine_xmalloc(VIDEOBUFSIZE + FF_INPUT_BUFFER_PADDING_SIZE);
+  this->buf               = calloc(1, VIDEOBUFSIZE + FF_INPUT_BUFFER_PADDING_SIZE);
   this->bufsize           = VIDEOBUFSIZE;
 
   this->is_mpeg12         = 0;
@@ -1581,6 +1590,10 @@ static video_decoder_t *ff_video_open_plugin (video_decoder_class_t *class_gen,
   
   this->dr1_frames        = xine_list_new();
 
+#ifdef LOG
+  this->debug_fmt = -1;
+#endif
+
   return &this->video_decoder;
 }
 
@@ -1601,7 +1614,7 @@ void *init_video_plugin (xine_t *xine, void *data) {
   ff_video_class_t *this;
   config_values_t  *config;
   
-  this = (ff_video_class_t *) xine_xmalloc (sizeof (ff_video_class_t));
+  this = calloc(1, sizeof (ff_video_class_t));
 
   this->decoder_class.open_plugin     = ff_video_open_plugin;
   this->decoder_class.get_identifier  = ff_video_get_identifier;
