@@ -15,15 +15,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  */
 
 /*
  * RoQ File Demuxer by Mike Melanson (melanson@pcisys.net)
  * For more information regarding the RoQ file format, visit:
  *   http://www.csse.monash.edu.au/~timf/
- *
- * $Id: demux_roq.c,v 1.54 2007/01/19 00:26:40 dgp85 Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -413,7 +411,7 @@ static demux_plugin_t *open_plugin (demux_class_t *class_gen, xine_stream_t *str
     return NULL;
   }
 
-  this         = xine_xmalloc (sizeof (demux_roq_t));
+  this         = calloc(1, sizeof(demux_roq_t));
   this->stream = stream;
   this->input  = input;
 
@@ -487,7 +485,7 @@ static void class_dispose (demux_class_t *this_gen) {
 void *demux_roq_init_plugin (xine_t *xine, void *data) {
   demux_roq_class_t     *this;
 
-  this  = xine_xmalloc (sizeof (demux_roq_class_t));
+  this  = calloc(1, sizeof(demux_roq_class_t));
 
   this->demux_class.open_plugin     = open_plugin;
   this->demux_class.get_description = get_description;
